THE_REAL_SHAQ (THE_REAL_SHAQ) on Twitter
Description: THE_REAL_SHAQ (THE_REAL_SHAQ) is on Twitter. Sign up for Twitter to follow THE_REAL_SHAQ (THE_REAL_SHAQ) and get their latest updates

- Skip past navigation
- On a mobile phone? Check out m.twitter.com!
- Skip to navigation
- Skip to sign in form

Have an account?Sign in

# Get short, timely messages from THE_REAL_SHAQ.

## Twitter is a rich source of instantly updated information. It's easy to stay updated on an incredibly wide variety of topics. Join today and follow @THE_REAL_SHAQ.

Get updates via SMS by texting follow THE_REAL_SHAQ to 40404 in the United States
Codes for other countries

Two-way (sending and receiving) short codes:
Country | Code | For customers of
--- | --- | ---
Australia | 0198089488 Telstra
Canada | 21212 (any)
United Kingdom | 86444 Vodafone, Orange, 3, O2
Indonesia | 89887 AXIS, 3, Telkomsel
Ireland | 51210 O2
India | 53000 Bharti Airtel, Videocon
Jordan | 90903 Zain
New Zealand | 8987 Vodafone, Telecom NZ
United States | 40404 (any)

## THE_REAL_SHAQ # I need all of my people to Watch my Nephew Cory Gunz New MTV Show "Son Of A Gunz" tonight at 11pm Eastern time. LET'S GO!!! 8:50 AM Apr 28th via TweetDeck @Christleen not tru 4:29 PM Apr 23rd via web in reply to Christleen @im_pappag copyshaq 4:27 PM Apr 23rd via web in reply to im_pappag @flocker289 yup 4:25 PM Apr 23rd via web in reply to flocker289 gsp ftw, dats all http://bit.ly/eo177i 3:54 PM Apr 23rd via web @yogi4change i like dat 3:02 PM Apr 12th via web in reply to yogi4change @jvhugg thanks man, hope u can help da kids 3:02 PM Apr 12th via web in reply to jvhugg @TrickyTre dats true 3:01 PM Apr 12th via web in reply to TrickyTre todays random act of shaqness, help out my little friends n be a childhelper http://bit.ly/hKFdFZ 2:56 PM Apr 12th via web did u already bust ur shaqet or u got #butler or #uconn winning it all? chat wit me during da #ncaa finals http://phi.tv/idOlGZ 6:12 PM Apr 4th via web u chattin when the @celtics beat da spurs tonight? best comment wins 2 free tickets from urs truly http://phi.tv/eVJWBo 2:27 PM Mar 31st via web twitter mirror twittrr mirror on da wall whos da best twitterer of dem all? http://ti.me/g85EUt 11:31 AM Mar 29th via web RT @realgranthill33: Me, @THE_REAL_SHAQ and James Brown in 1996 http://t.co/qOMoz0Y 8:42 AM Mar 27th via Twitter for iPhone im chatting live during da #duke vs #arizona game, come join march shaqness lol http://phi.tv/fZsSxo #marchmadness 5:54 PM Mar 24th via web check out @jonnybones on da @jayleno sho tonite 11:35pm ET http://bit.ly/enCsFO 5:52 PM Mar 24th via web u complete me twitter, lol http://t.co/Riq93H4 7:09 PM Mar 21st via Twitter for iPhone @peterfitz I agree 8:28 PM Mar 20th via ÜberSocial in reply to peterfitz @SamTecle hell yeah 8:28 PM Mar 20th via ÜberSocial in reply to SamTecle @JOHELCD yes sir 8:28 PM Mar 20th via ÜberSocial in reply to JOHELCD @tamaAK87 I hope so bro 8:25 PM Mar 20th via ÜberSocial in reply to tamaAK87 more |
632 Following | 3,773,066 Followers | 37,759 Listed
## Following RSS feed of THE_REAL_SHAQ's tweets RSS feed of THE_REAL_SHAQ's favorites